aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2024-08-14 13:53:22 +0200
committerJoas Schilling <coding@schilljs.com>2024-08-14 13:53:22 +0200
commit5a554100830df287f96568328d00ad7544ce8480 (patch)
treeb59cb0df649aa88a3e26bcc04724ec0bbcabe76d
parent2659b2113d9d4c3c34609ecf99591f2f9f66bc44 (diff)
downloadnextcloud-server-5a554100830df287f96568328d00ad7544ce8480.tar.gz
nextcloud-server-5a554100830df287f96568328d00ad7544ce8480.zip
chore(branchoff): Test against stable30 branches
Signed-off-by: Joas Schilling <coding@schilljs.com>
-rw-r--r--.github/workflows/integration-sqlite.yml2
-rw-r--r--.github/workflows/performance.yml4
-rw-r--r--README.md4
-rwxr-xr-xbuild/update-apps.sh8
-rwxr-xr-xbuild/update.sh6
-rw-r--r--codecov.yml2
6 files changed, 13 insertions, 13 deletions
diff --git a/.github/workflows/integration-sqlite.yml b/.github/workflows/integration-sqlite.yml
index 02666582369..058745a12c3 100644
--- a/.github/workflows/integration-sqlite.yml
+++ b/.github/workflows/integration-sqlite.yml
@@ -70,7 +70,7 @@ jobs:
- 'videoverification_features'
php-versions: ['8.2']
- spreed-versions: ['main']
+ spreed-versions: ['stable30']
services:
redis:
diff --git a/.github/workflows/performance.yml b/.github/workflows/performance.yml
index e4670be0588..6a0738fb661 100644
--- a/.github/workflows/performance.yml
+++ b/.github/workflows/performance.yml
@@ -64,7 +64,7 @@ jobs:
curl -s -u test:test -T README.md http://localhost:8080/remote.php/dav/files/test/new_file.txt
curl -s -u test:test -X DELETE http://localhost:8080/remote.php/dav/files/test/new_file.txt
output: before.json
- profiler-branch: master
+ profiler-branch: stable30
- name: Apply PR
run: |
@@ -86,7 +86,7 @@ jobs:
curl -s -u test:test -T README.md http://localhost:8080/remote.php/dav/files/test/new_file.txt
curl -s -u test:test -X DELETE http://localhost:8080/remote.php/dav/files/test/new_file.txt
output: after.json
- profiler-branch: master
+ profiler-branch: stable30
compare-with: before.json
- name: Upload profiles
diff --git a/README.md b/README.md
index 119cad6d412..6eab8c7d4a5 100644
--- a/README.md
+++ b/README.md
@@ -5,8 +5,8 @@
-->
# Nextcloud Server ☁
[![REUSE status](https://api.reuse.software/badge/github.com/nextcloud/server)](https://api.reuse.software/info/github.com/nextcloud/server)
-[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/nextcloud/server/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/nextcloud/server/?branch=master)
-[![codecov](https://codecov.io/gh/nextcloud/server/branch/master/graph/badge.svg)](https://codecov.io/gh/nextcloud/server)
+[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/nextcloud/server/badges/quality-score.png?b=stable30)](https://scrutinizer-ci.com/g/nextcloud/server/?branch=stable30)
+[![codecov](https://codecov.io/gh/nextcloud/server/branch/stable30/graph/badge.svg)](https://codecov.io/gh/nextcloud/server)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/209/badge)](https://bestpractices.coreinfrastructure.org/projects/209)
[![Design](https://contribute.design/api/shield/nextcloud/server)](https://contribute.design/nextcloud/server)
diff --git a/codecov.yml b/codecov.yml
index 20139e01114..446183cff23 100644
--- a/codecov.yml
+++ b/codecov.yml
@@ -1,7 +1,7 @@
# SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
# SPDX-License-Identifier: AGPL-3.0-or-later
codecov:
- branch: master
+ branch: stable30
ci:
- drone.nextcloud.com
- '!scrutinizer-ci.com'
diff --git a/build/update-apps.sh b/build/update-apps.sh
index 444fd84c73e..1abba221408 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -3,16 +3,16 @@
# SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
# SPDX-License-Identifier: AGPL-3.0-or-later
#
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable30 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable30 | grep -v "stable30$" | xargs git branch -d && cd ..' \;
@@ -3,16 +3,16 @@
# SPDX-License-Identifier: AGPL-3.0-or-later
#
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable30
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -3,16 +3,16 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable30 and pulls quietly
# - shows the 3 most recent commits for context
@@ -3,16 +3,16 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable30
# - … could even do the build steps if they are consistent for the apps (like `make`)
diff --git a/build/update.sh b/build/update.sh
index 4f20535d917..6a45166bea7 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -3,17 +3,17 @@
# SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
# SPDX-License-Identifier: AGPL-3.0-or-later
#
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable30
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable30 | grep -v "stable30$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -3,17 +3,17 @@
# SPDX-License-Identifier: AGPL-3.0-or-later
#
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable30
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`